pub struct AuthenticationSecret(pub [u8; 16]);Expand description
A sequence of 16 octets generated by the user agent to act as a symmetric key and will be mixed into the key generation process as described in [https://datatracker.ietf.org/doc/html/rfc8291#section-3.2](RFC 8291 Section 3.2).
Tuple Fields
0: [u8; 16]Trait Implementations
Sourceimpl AsRef<[u8]> for AuthenticationSecret
impl AsRef<[u8]> for AuthenticationSecret
Sourceimpl Clone for AuthenticationSecret
impl Clone for AuthenticationSecret
Sourcefn clone(&self) -> AuthenticationSecret
fn clone(&self) -> AuthenticationSecret
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthenticationSecret
impl Debug for AuthenticationSecret
Sourceimpl<'de> Deserialize<'de> for AuthenticationSecret
impl<'de> Deserialize<'de> for AuthenticationSecret
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AuthenticationSecret
Sourceimpl Hash for AuthenticationSecret
impl Hash for AuthenticationSecret
Sourceimpl PartialEq for AuthenticationSecret
impl PartialEq for AuthenticationSecret
Sourcefn eq(&self, other: &AuthenticationSecret) -> bool
fn eq(&self, other: &AuthenticationSecret) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AuthenticationSecret
impl Serialize for AuthenticationSecret
impl StructuralPartialEq for AuthenticationSecret